# Developing

## Main library

To develop the main library, clone this repository and, from the main directory, use

```
git clone https://github.com/experimaestro/datamaestro.git
pip install -e .
```

to install the command line tool and develop at the same time.
